@@ -1,5 +1,6 @@
 from manim import *
 
+from powermanim.layouts.arrangedbullets import Bullet
 from powermanim.showcase.showcasescene import ShowcaseScene
 from powermanim.templates.bulletlist import BulletList
 
@@ -10,13 +11,12 @@ class BulletListShowcase(ShowcaseScene):
 
     def construct(self):
         rows = [
-            Text(row)
-            for row in [
-                "First row",
-                "Second row",
-                "Third row",
-                "Fourth row",
-            ]
+            Bullet(Text("First row"), group=0),
+            Bullet(Text("Second row"), group=1),
+            Bullet(Text("Elements:"), group=2),
+            Bullet(Text("First element"), level=1, symbol="(1)", group=3),
+            Bullet(Text("Second element"), level=1, symbol="(2)", group=4),
+            Bullet(Text("Third element"), level=1, symbol="(3)", group=5),
         ]
         VGroup(*rows).set_opacity(0.5).scale(0.8)
 
@@ -30,10 +30,14 @@ class BulletListShowcase(ShowcaseScene):
         bullets.also_next(self)
         bullets.also_next(self)
         bullets.also_next(self)
+        bullets.also_next(self)
+        bullets.also_next(self)
         bullets.clear(self)
         bullets.only_next(self)
         bullets.only_next(self)
         bullets.only_next(self)
         bullets.only_next(self)
+        bullets.only_next(self)
+        bullets.only_next(self)
         bullets.clear(self)
         self.wait()
